import { View, Image, Text } from "@tarojs/components";
import { transferImage } from '@/utils/tools'
import dayjs from 'dayjs'
import emptyImg from '@/assets/empty.png'
import copyImg from '../../assets/copy.png'
import closeImg from '../../assets/close.png'

import './index.scss'

export default function HouseCard(props) {
  const {
    buildingName,
    termname,
    blockName,
    unitName,
    roomName,
    price,
    housingStatus,
    saleBatchStatus,
    apartmentName,
    houseId,
    createDate,
    status = 1,
    area1,
    area2,
    code,
    buildingImgList = [],
  } = props.summary || {}

  const title = `${buildingName} ${termname || ''} ${blockName} ${unitName} ${roomName}`
  const thumb = (buildingImgList || []).length
  const showDT = dayjs(createDate).format('YYYY/MM/DD')
  const wanY = Number(price)

  const toHouseDetail = () => {
    if (housingStatus == '0' || saleBatchStatus == '0') {
      Taro.showToast({ title: '当前销售批次或该房源已被取消发布', icon: 'none', duration: 2000 })
    } else {
      Taro.navigateTo({
        url: `/onlineSelling/pages/detail/index?id=${houseId}`
      })
    }
  }
  const copyData = (e) => {
    e.stopPropagation()
    Taro.setClipboardData({
      data: code,
      onSuccess: (() => { }),
    })
  }
  return (
    <View className="housecard" style={props.style}>
      <View className="head" onClick={toHouseDetail}>
        {thumb ? <Image className="thumb" src={transferImage((buildingImgList)[0].url)} mode="aspectFit" /> :
          <Text style="font-size:26rpx;color:#666">暂无户型图</Text>
        }
      </View>
      <View className="body" onClick={toHouseDetail}>
        {props.type == 'raiseMoney' && <Image src={closeImg} className="close-img"></Image>}
        {!props.type && <View className={status == '1' ? 'raised badge' : status == '2' ? 'unraise badge' : 'badge'}>{status == '1' ? '已缴费' : '未缴费'}</View>}
        {(props.type == 'raiseProfile' || props.type == 'houseResource') && <View style="color:#FF3C3C" className={status == '1' ? 'raised badge' : status == '2' ? 'unraise badge' : 'badge'}>{status == '1' ? '已锁给我' : '未缴费'}</View>}
        {props.type == 'raiseProfile' || props.type == 'raiseMoney' && <View style={props.type == 'raiseMoney' ? 'color:#BB9C79;font-size:30rpx' : 'color:#BB9C79;font-size:30rpx;margin-top:-20rpx'}>{apartmentName}</View>}
        {props.type == 'raiseMoney' && <View className="red-price">现价{Number(price) + 0}万</View>}
        {props.type == 'houseResource' && <View style="color:#BB9C79;font-size:28rpx;margin:-40rpx 0 26rpx 0">未锁定/已锁定</View>}
        <View className="title">{title}</View>
        {!props.type && <View className="meta">{showDT}</View>}
        {props.type == 'raiseProfile' && <View className="price">现价<Text className="red">{Number(price) + 0}</Text>万</View>}

        {props.type == 'raiseProfile' || props.type == 'raiseMoney' && <View className="area">建筑面积约<Text className="red">{area1}m²</Text></View>}
        {props.type == 'raiseProfile' || props.type == 'raiseMoney' && <View className="area">使用面积约<Text className="red">{area2}m²</Text></View>}
        {props.type == 'houseResource' && <View className="house-code" style="margin-top:26rpx">房源编号：{code}
          <Image src={copyImg} className="copy-img" onClick={copyData}></Image>
        </View>}
      </View>

    </View>
  )
}
